Installation
==================

Use pip to install CrossMap
-----------------------------

::

 pip3 install git+https://github.com/liguowang/CrossMap.git
 
 or 
 
 pip3 install CrossMap


Documentation
=============

https://crossmap.readthedocs.io/en/latest/ 

